==> portal-contribuinte-2.002.1.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-geracao-lote-impressao.sql <==
SELECT CALCULOCADASTRO.ID IDCALCULOCADASTRO
%s
FROM CALCULOCADASTRO CALCULOCADASTRO
LEFT JOIN TRIBCADASTROGERAL TRIBCADASTROGERAL ON CALCULOCADASTRO.CADASTRO = TRIBCADASTROGERAL.IDKEY
LEFT JOIN TRIBCADASTROIMOBILIARIO TRIBCADASTROIMOBILIARIO ON TRIBCADASTROGERAL.TIPOCADASTRO = TRIBCADASTROIMOBILIARIO.TIPOCADASTRO
                                                         AND TRIBCADASTROGERAL.CADASTROGERAL = TRIBCADASTROIMOBILIARIO.CADASTROGERAL

LEFT JOIN TRIBQUADRICULA TRIBQUADRICULA ON TRIBCADASTROIMOBILIARIO.QUADRICULA_INSCRICAOCADASTRAL = TRIBQUADRICULA.QUADRICULA
LEFT JOIN TRIBDISTRITO TRIBDISTRITO ON TRIBCADASTROIMOBILIARIO.DISTRITO_INSCRICAOCADASTRAL = TRIBDISTRITO.DISTRITO
LEFT JOIN TRIBSETOR TRIBSETOR ON TRIBCADASTROIMOBILIARIO.TRIBSETOR_IDKEY = TRIBSETOR.IDKEY
LEFT JOIN TRIBIMOBILIARIA TRIBIMOBILIARIA ON TRIBCADASTROIMOBILIARIO.IMOBILIARIA = TRIBIMOBILIARIA.IMOBILIARIA
LEFT JOIN PESSOA PESSOAIMOBILIARIO ON TRIBIMOBILIARIA.PESSOA = PESSOAIMOBILIARIO.PESSOA
LEFT JOIN TRIBIMOBILIARIOTESTADA TRIBIMOBILIARIOTESTADA ON TRIBIMOBILIARIOTESTADA.TRIBCADASTROGERAL_IDKEY = TRIBCADASTROIMOBILIARIO.TRIBCADASTROGERAL_IDKEY AND TRIBIMOBILIARIOTESTADA.PRINCIPAL = 'S'
LEFT JOIN TRIBLOGRADOUROTESTADA TRIBLOGRADOUROTESTADA ON TRIBLOGRADOUROTESTADA.IDLOGRADOUROTESTADA = TRIBIMOBILIARIOTESTADA.IDLOGRADOUROTESTADA
LEFT JOIN CIDADE ON TRIBCADASTROGERAL.CIDADE = CIDADE.CIDADE
WHERE CALCULOCADASTRO.CALCULO = :IDCALCULO
AND CALCULOCADASTRO.IDDEBITO IS NOT NULL
AND EXISTS (SELECT CALCULORESULTADO.ID
            FROM CALCULORESULTADO CALCULORESULTADO
            LEFT OUTER JOIN CALCULORESULTADODEDUCAO CALCULORESULTADODEDUCAO ON CALCULORESULTADO.ID = CALCULORESULTADODEDUCAO.CALCULORESULTADO
            WHERE CALCULORESULTADO.CALCULOCADASTRO = CALCULOCADASTRO.ID
            GROUP BY CALCULORESULTADO.ID
            HAVING CALCULORESULTADO.VALOR - SUM(COALESCE(CALCULORESULTADODEDUCAO.VALOR,0)) > 0)
AND NOT EXISTS (SELECT 1
                FROM CALCULOGERACAOLOTE CONFIGURACAO
                INNER JOIN CALCULOLOTEIMPRESSAO LOTE ON CONFIGURACAO.ID = LOTE.IDGERACAOLOTE
                INNER JOIN CALCULOLOTEIMPRESSAOITEM ITEM ON LOTE.ID = ITEM.IDCALCULOLOTEIMPRESSAO
                WHERE CONFIGURACAO.IDCALCULO = CALCULOCADASTRO.CALCULO
                AND   ITEM.IDCALCULOCADASTRO = CALCULOCADASTRO.ID)
%s
%s

==> portal-contribuinte-3.034.1.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-geracao-lote-impressao.sql <==
SELECT CALCULOCADASTRO.ID IDCALCULOCADASTRO
%s
FROM CALCULOCADASTRO CALCULOCADASTRO
LEFT JOIN TRIBCADASTROGERAL TRIBCADASTROGERAL ON CALCULOCADASTRO.CADASTRO = TRIBCADASTROGERAL.IDKEY
LEFT JOIN TRIBCADASTROIMOBILIARIO TRIBCADASTROIMOBILIARIO ON TRIBCADASTROGERAL.TIPOCADASTRO = TRIBCADASTROIMOBILIARIO.TIPOCADASTRO
                                                         AND TRIBCADASTROGERAL.CADASTROGERAL = TRIBCADASTROIMOBILIARIO.CADASTROGERAL

LEFT JOIN TRIBQUADRICULA TRIBQUADRICULA ON TRIBCADASTROIMOBILIARIO.QUADRICULA_INSCRICAOCADASTRAL = TRIBQUADRICULA.QUADRICULA
LEFT JOIN TRIBDISTRITO TRIBDISTRITO ON TRIBCADASTROIMOBILIARIO.DISTRITO_INSCRICAOCADASTRAL = TRIBDISTRITO.DISTRITO
LEFT JOIN TRIBSETOR TRIBSETOR ON TRIBCADASTROIMOBILIARIO.TRIBSETOR_IDKEY = TRIBSETOR.IDKEY
LEFT JOIN TRIBIMOBILIARIA TRIBIMOBILIARIA ON TRIBCADASTROIMOBILIARIO.IMOBILIARIA = TRIBIMOBILIARIA.IMOBILIARIA
LEFT JOIN PESSOA PESSOAIMOBILIARIO ON TRIBIMOBILIARIA.PESSOA = PESSOAIMOBILIARIO.PESSOA
LEFT JOIN TRIBIMOBILIARIOTESTADA TRIBIMOBILIARIOTESTADA ON TRIBIMOBILIARIOTESTADA.TRIBCADASTROGERAL_IDKEY = TRIBCADASTROIMOBILIARIO.TRIBCADASTROGERAL_IDKEY AND TRIBIMOBILIARIOTESTADA.PRINCIPAL = 'S'
LEFT JOIN TRIBLOGRADOUROTESTADA TRIBLOGRADOUROTESTADA ON TRIBLOGRADOUROTESTADA.IDLOGRADOUROTESTADA = TRIBIMOBILIARIOTESTADA.IDLOGRADOUROTESTADA
LEFT JOIN CIDADE ON TRIBCADASTROGERAL.CIDADE = CIDADE.CIDADE
WHERE CALCULOCADASTRO.CALCULO = :IDCALCULO
AND CALCULOCADASTRO.IDDEBITO IS NOT NULL
AND EXISTS (SELECT CALCULORESULTADO.ID
              FROM CALCULORESULTADO CALCULORESULTADO
             WHERE CALCULORESULTADO.CALCULOCADASTRO = CALCULOCADASTRO.ID
               AND CALCULORESULTADO.VALOR > COALESCE((SELECT SUM(CALCULORESULTADODEDUCAO.VALOR)
                                                        FROM CALCULORESULTADODEDUCAO CALCULORESULTADODEDUCAO
                                                       WHERE CALCULORESULTADO.ID = CALCULORESULTADODEDUCAO.CALCULORESULTADO),0))
AND NOT EXISTS (SELECT 1
                FROM CALCULOGERACAOLOTE CONFIGURACAO
                INNER JOIN CALCULOLOTEIMPRESSAO LOTE ON CONFIGURACAO.ID = LOTE.IDGERACAOLOTE
                INNER JOIN CALCULOLOTEIMPRESSAOITEM ITEM ON LOTE.ID = ITEM.IDCALCULOLOTEIMPRESSAO
                WHERE CONFIGURACAO.IDCALCULO = CALCULOCADASTRO.CALCULO
                AND   ITEM.IDCALCULOCADASTRO = CALCULOCADASTRO.ID)
%s
%s
